#[non_exhaustive]pub enum Error {
Show 13 variants
OpenIdentityCertFile {
path: PathBuf,
source: Error,
},
ReadIdentityCertFile {
path: PathBuf,
source: Error,
},
ParseIdentityCertFile {
path: PathBuf,
source: Error,
},
BuildRequestClient(Error),
ParseUrl {
url: String,
source: ParseError,
},
OpenIconFile {
path: PathBuf,
source: Error,
},
ReadIconFile {
path: PathBuf,
source: Error,
},
EncodePayload(Error),
HttpRequest(Error),
HttpResponse {
url: Url,
status: StatusCode,
error_response: ErrorResponse,
source: Error,
},
ReceiveResponseBody(Error),
DeserializeResponseBody(Error),
SerializeSearchPredicate(Error),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OpenIdentityCertFile
Failed to open identity certificate file at the specified path.
ReadIdentityCertFile
Failed to read identity certificate file at the specified path.
ParseIdentityCertFile
Failed parsing identity certificate file at the specified path.
BuildRequestClient(Error)
Failed building request client.
ParseUrl
Failed to parse URL.
OpenIconFile
Failed to open icon file at the specified path.
ReadIconFile
Failed to read icon file at the specified path.
EncodePayload(Error)
Failed to encode payload.
HttpRequest(Error)
HTTP request error.
HttpResponse
HTTP response error.
ReceiveResponseBody(Error)
Failed receiving the server’s response body.
DeserializeResponseBody(Error)
Failed decoding the server’s response body.
SerializeSearchPredicate(Error)
Failed to url-encode the search predicate.